#!/usr/bin/env python3
# MIT License

# Copyright (c) 2023 Kevin Walchko

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
from .cmd import Command

class Pip(Command):

    def outdated(self):
        # out = self.run("pip3 list --outdated | cut -d' ' -f1 | awk 'NR > 2'")
        out = self.run("pip3 list --outdated")
        out = out.split("\n")
        out = [x.split(" ")[0] for x in out[2:] if len(x) > 0]
        return out

    def update(self, packages):
        if isinstance(packages, list) and len(packages) > 0:
            # packages = " ".join(packages)
            for pack in packages:
                out = self.run(f"pip3 install -U {pack}")
                print(out)
        elif isinstance(packages,str) and len(packages) > 0:
            out = self.run(f"pip3 install -U {packages}")
            print(out)
        else:
            print("Already up to date")

def update():
    cmd = Pip()
    out = cmd.outdated()
    cmd.update(out)

